@@ -13,10 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 import horizon
 
 
 class AuditTemplates(horizon.Panel):
     name = _("Audit Templates")
     slug = "audit_templates"
+    permissions = ("openstack.services.infra-optim",)
